@@ -1,6 +1,6 @@
 /* coap_time.c -- Clock Handling
  *
- * Copyright (C) 2015 Olaf Bergmann <bergmann@tzi.org>
+ * Copyright (C) 2015,2023 Olaf Bergmann <bergmann@tzi.org>
  *
  * SPDX-License-Identifier: BSD-2-Clause
  *
@@ -31,13 +31,13 @@
 static coap_tick_t coap_clock_offset = 0;
 
 #if _POSIX_TIMERS && !defined(__APPLE__)
-  /* _POSIX_TIMERS is > 0 when clock_gettime() is available */
+/* _POSIX_TIMERS is > 0 when clock_gettime() is available */
 
-  /* Use real-time clock for correct timestamps in coap_log(). */
+/* Use real-time clock for correct timestamps in coap_log(). */
 #define COAP_CLOCK CLOCK_REALTIME
 #endif
 
-#ifdef HAVE_WINSOCK2_H
+#if defined(HAVE_WINSOCK2_H) && !defined(__MINGW32__)
 static int
 gettimeofday(struct timeval *tp, TIME_ZONE_INFORMATION *tzp) {
   (void)tzp;
@@ -47,16 +47,16 @@ gettimeofday(struct timeval *tp, TIME_ZONE_INFORMATION *tzp) {
   ULARGE_INTEGER time;
   uint64_t tUsSinceUnicEpoch;
 
-  GetSystemTimeAsFileTime( &file_time );
+  GetSystemTimeAsFileTime(&file_time);
   time.LowPart = file_time.dwLowDateTime;
   time.HighPart = file_time.dwHighDateTime;
-  tUsSinceUnicEpoch = ( time.QuadPart - s_tUnixEpoch ) / 10;
+  tUsSinceUnicEpoch = (time.QuadPart - s_tUnixEpoch) / 10;
 
   tp->tv_sec = (long)(tUsSinceUnicEpoch / 1000000);
   tp->tv_usec = (long)(tUsSinceUnicEpoch % 1000000);
   return 0;
 }
-#endif
+#endif /* HAVE_WINSOCK2_H && !__MINGW32__ */
 
 void
 coap_clock_init(void) {
@@ -118,11 +118,13 @@ coap_ticks_to_rt(coap_tick_t t) {
   return coap_clock_offset + (t / COAP_TICKS_PER_SECOND);
 }
 
-uint64_t coap_ticks_to_rt_us(coap_tick_t t) {
+uint64_t
+coap_ticks_to_rt_us(coap_tick_t t) {
   return (uint64_t)coap_clock_offset * 1000000 + (uint64_t)t * 1000000 / COAP_TICKS_PER_SECOND;
 }
 
-coap_tick_t coap_ticks_from_rt_us(uint64_t t) {
+coap_tick_t
+coap_ticks_from_rt_us(uint64_t t) {
   return (coap_tick_t)((t - (uint64_t)coap_clock_offset * 1000000) * COAP_TICKS_PER_SECOND / 1000000);
 }
 
@@ -132,10 +134,14 @@ coap_tick_t coap_ticks_from_rt_us(uint64_t t) {
 
 #else /* HAVE_TIME_H */
 
-/* make compilers happy that do not like empty modules */
-COAP_STATIC_INLINE void dummy(void)
-{
+#ifdef __clang__
+/* Make compilers happy that do not like empty modules. As this function is
+ * never used, we ignore -Wunused-function at the end of compiling this file
+ */
+#pragma GCC diagnostic ignored "-Wunused-function"
+#endif
+COAP_STATIC_INLINE void
+dummy(void) {
 }
 
 #endif /* not HAVE_TIME_H */
-
