@@ -1,6 +1,6 @@
 /* libcoap unit tests
  *
- * Copyright (C) 2012,2015 Olaf Bergmann <bergmann@tzi.org>
+ * Copyright (C) 2012,2015,2022-2023 Olaf Bergmann <bergmann@tzi.org>
  *
  * SPDX-License-Identifier: BSD-2-Clause
  *
@@ -181,11 +181,14 @@ t_parse_uri7(void) {
 
 static void
 t_parse_uri8(void) {
+  coap_log_t level = coap_get_log_level();
   char teststr[] = "http://example.com/%7E%AB%13";
   int result;
   coap_uri_t uri;
 
+  coap_set_log_level(COAP_LOG_CRIT);
   result = coap_split_uri((unsigned char *)teststr, strlen(teststr), &uri);
+  coap_set_log_level(level);
   if (result < 0) {
     CU_PASS("detected non-coap URI");
   } else {
@@ -195,11 +198,14 @@ t_parse_uri8(void) {
 
 static void
 t_parse_uri9(void) {
+  coap_log_t level = coap_get_log_level();
   char teststr[] = "http://example.com/%x";
   int result;
   coap_uri_t uri;
 
+  coap_set_log_level(COAP_LOG_CRIT);
   result = coap_split_uri((unsigned char *)teststr, strlen(teststr), &uri);
+  coap_set_log_level(level);
   if (result < 0) {
     CU_PASS("detected non-coap URI");
   } else {
@@ -233,7 +239,7 @@ t_parse_uri10(void) {
 static void
 t_parse_uri11(void) {
   char teststr[] =
-    "coap://xn--18j4d.example/%E3%81%93%E3%82%93%E3%81%AB%E3%81%A1%E3%81%AF";
+      "coap://xn--18j4d.example/%E3%81%93%E3%82%93%E3%81%AB%E3%81%A1%E3%81%AF";
   int result;
   coap_uri_t uri;
   unsigned char buf[40];
@@ -333,7 +339,7 @@ t_parse_uri13(void) {
 
   coap_pdu_t pdu = {
     .max_size = sizeof(teststr),
-    .token_length = 0,
+    .e_token_length = 0,
     .token = teststr,
     .used_size = sizeof(teststr)
   };
@@ -343,13 +349,13 @@ t_parse_uri13(void) {
   CU_ASSERT(uri_path->length == sizeof(COAP_DEFAULT_URI_WELLKNOWN)-1);
   CU_ASSERT_NSTRING_EQUAL(uri_path->s, COAP_DEFAULT_URI_WELLKNOWN,
                           sizeof(COAP_DEFAULT_URI_WELLKNOWN)-1);
-  coap_delete_string (uri_path);
+  coap_delete_string(uri_path);
 }
 
 static void
 t_parse_uri14(void) {
   char teststr[] =
-    "longerthan13lessthan270=0123456789012345678901234567890123456789";
+      "longerthan13lessthan270=0123456789012345678901234567890123456789";
   int result;
 
   /* buf is large enough to hold sizeof(teststr) - 1 bytes content and
@@ -372,7 +378,7 @@ t_parse_uri14(void) {
 static void
 t_parse_uri15(void) {
   char teststr[] =
-    "longerthan13lessthan270=0123456789012345678901234567890123456789";
+      "longerthan13lessthan270=0123456789012345678901234567890123456789";
   int result;
 
   /* buf is too small to hold sizeof(teststr) - 1 bytes content and 2
@@ -388,7 +394,7 @@ t_parse_uri15(void) {
 static void
 t_parse_uri16(void) {
   char teststr[] =
-    "longerthan13lessthan270=0123456789012345678901234567890123456789";
+      "longerthan13lessthan270=0123456789012345678901234567890123456789";
   int result;
 
   /* buf is too small to hold the option header. */
@@ -403,12 +409,12 @@ t_parse_uri16(void) {
 static void
 t_parse_uri17(void) {
   char teststr[] =
-    "thisislongerthan269="
-    "01234567890123456789012345678901234567890123456789"
-    "01234567890123456789012345678901234567890123456789"
-    "01234567890123456789012345678901234567890123456789"
-    "01234567890123456789012345678901234567890123456789"
-    "01234567890123456789012345678901234567890123456789";
+      "thisislongerthan269="
+      "01234567890123456789012345678901234567890123456789"
+      "01234567890123456789012345678901234567890123456789"
+      "01234567890123456789012345678901234567890123456789"
+      "01234567890123456789012345678901234567890123456789"
+      "01234567890123456789012345678901234567890123456789";
   int result;
 
   /* buf is large enough to hold sizeof(teststr) - 1 bytes content and
@@ -434,7 +440,7 @@ t_parse_uri18(void) {
   uint8_t token[1] = "";
   coap_pdu_t pdu = {
     .max_size = 0,
-    .token_length = 0,
+    .e_token_length = 0,
     .token = token,
     .used_size = 0
   };
@@ -447,7 +453,7 @@ t_parse_uri18(void) {
   /* strings are stored with terminating zero */
   CU_ASSERT_NSTRING_EQUAL(uri_path->s, "", 1);
 #endif
-  coap_delete_string (uri_path);
+  coap_delete_string(uri_path);
 }
 
 static void
@@ -459,7 +465,7 @@ t_parse_uri19(void) {
 
   coap_pdu_t pdu = {
     .max_size = sizeof(teststr),
-    .token_length = 0,
+    .e_token_length = 0,
     .token = teststr,
     .used_size = sizeof(teststr)
   };
@@ -468,7 +474,7 @@ t_parse_uri19(void) {
 
   CU_ASSERT(uri_path->length == 4);
   CU_ASSERT_NSTRING_EQUAL(uri_path->s, "foo/", 4);
-  coap_delete_string (uri_path);
+  coap_delete_string(uri_path);
 }
 
 static void
@@ -479,7 +485,7 @@ t_parse_uri20(void) {
 
   coap_pdu_t pdu = {
     .max_size = sizeof(teststr),
-    .token_length = 0,
+    .e_token_length = 0,
     .token = teststr,
     .used_size = sizeof(teststr)
   };
@@ -489,7 +495,7 @@ t_parse_uri20(void) {
   /* The leading '/' is stripped hence only one '/' remains. */
   CU_ASSERT(uri_path->length == 1);
   CU_ASSERT_NSTRING_EQUAL(uri_path->s, "/", 1);
-  coap_delete_string (uri_path);
+  coap_delete_string(uri_path);
 }
 
 static void
@@ -500,7 +506,7 @@ t_parse_uri21(void) {
 
   coap_pdu_t pdu = {
     .max_size = sizeof(teststr),
-    .token_length = 0,
+    .e_token_length = 0,
     .token = teststr,
     .used_size = sizeof(teststr)
   };
@@ -510,7 +516,7 @@ t_parse_uri21(void) {
   /* The leading '/' is stripped hence only one '/' remains. */
   CU_ASSERT(uri_path->length == 4);
   CU_ASSERT_NSTRING_EQUAL(uri_path->s, "/foo", 4);
-  coap_delete_string (uri_path);
+  coap_delete_string(uri_path);
 }
 
 static void
@@ -523,7 +529,7 @@ t_parse_uri22(void) {
 
   coap_pdu_t pdu = {
     .max_size = sizeof(teststr),
-    .token_length = 0,
+    .e_token_length = 0,
     .token = teststr,
     .used_size = sizeof(teststr)
   };
@@ -532,7 +538,7 @@ t_parse_uri22(void) {
 
   CU_ASSERT(uri_path->length == 16);
   CU_ASSERT_NSTRING_EQUAL(uri_path->s, "-._~!$&'()/*+,;=", 16);
-  coap_delete_string (uri_path);
+  coap_delete_string(uri_path);
 }
 
 static void
@@ -544,7 +550,7 @@ t_parse_uri23(void) {
 
   coap_pdu_t pdu = {
     .max_size = sizeof(teststr),
-    .token_length = 0,
+    .e_token_length = 0,
     .token = teststr,
     .used_size = sizeof(teststr)
   };
@@ -553,7 +559,7 @@ t_parse_uri23(void) {
 
   CU_ASSERT(uri_path->length == 15);
   CU_ASSERT_NSTRING_EQUAL(uri_path->s, "%25%20%23%5B%5D", 15);
-  coap_delete_string (uri_path);
+  coap_delete_string(uri_path);
 }
 
 /*
@@ -620,4 +626,3 @@ t_init_uri_tests(void) {
 
   return suite;
 }
-
